from django.db import models
from django.contrib.auth.models import User

class Appearance(models.Model):
	face_x = models.FloatField()
	face_y = models.FloatField()
	face_w = models.SmallIntegerField()
	face_h = models.SmallIntegerField()
	user = models.ForeignKey(User)
	
	def __str__(self):
		return self.user.username
		
class InstrumentType(models.Model):
	name = models.CharField(max_length=30)
	
	def __str__(self):
		return self.name
		
class InstrumentBrand(models.Model):
	name = models.CharField(max_length=30)
	
	def __str__(self):
		return self.name
		
class InstrumentModel(models.Model):
	name = models.CharField(max_length=30)
	type = models.ForeignKey(InstrumentType)
	brand = models.ForeignKey(InstrumentBrand)
	
	def __str__(self):
		return self.name
		
class UserInstrument(models.Model):
	user = models.ForeignKey(User)
	instrument = models.ManyToManyField(InstrumentModel)
	
	def __str__(self):
		return self.user.username

class Band(models.Model):
	name = models.CharField(max_length=30)
	members = models.ManyToManyField(User)
	
	def __str__(self):
		return self.name

class UserBand(models.Model):
	user = models.ForeignKey(User)
	bands = models.ManyToManyField(Band)
	
	def __str__(self):
		return self.user.username
		
class BandRequest(models.Model):
	user = models.ForeignKey(User)
	band = models.ForeignKey(Band)
	request_username = models.CharField(max_length=30)
	
	def __str__(self):
		return self.user.username
		
class PracticeLocal(models.Model):
	name = models.CharField(max_length=30)
	
	def __str__(self):
		return self.name

class BandTimetable(models.Model):
	band = models.ForeignKey(Band)
	local = models.ForeignKey(PracticeLocal)
	dia = models.SmallIntegerField()
	hora_inicio = models.SmallIntegerField()
	hora_fin = models.SmallIntegerField()
	
	def __str__(self):
		return self.band.name+"-"+self.local.name
